import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/Mgk1255/bc891560286f368e7c9a192dd4528a07/raw/3e2b1a223fd0e520f580a0215fb2398ea992402d/raw_data.csv', 
].join('');

const parseRow = (d) => {
  d.calyx_Length = +d.calyx_Length;
  d.calyx_Width = +d.calyx_Width;
  d.corolla_length = +d.corolla_length;
  d.corolla_width = +d.corolla_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.corolla_length;
const yValue = (d) => d.corolla_width;
const rxValue = (d) => d.calyx_Length;
const ryValue = (d) => d.calyx_Width;
const gladiousValue = (d) => d.gladious;
const colorValue = d => d.gladious;
const colorLabel = 'gladious';

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.corolla_width);
  const y = yValue((d) => d.calyx_Length);
  const marker = (d) => {
        	switch(d){
            case 'gladious-abbreviatus':
              return 'red';
            case 'gladious-abyssinicus':
              return 'blue';
            default:
              return 'yellow';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.corolla_width),
          y: yValue((d) => d.calyx_Length),
          gladious: gladiousValue(d),
          color: marker(gladiousValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.corolla_width)
    .yValue((d) => d.calyx_Length)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);

//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

const columns = [
    'corolla_width',
    'calyx_Width',
    'corolla_length',
    'calyx_Length',
  ];

  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'corolla_width',
    'calyx_Width',
    'corolla_length',
    'calyx_Length'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Gladious Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("abbreviatus").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("abyssinicus").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("acuminatus").style("font-size", "20px").attr("alignment-baseline","middle")
    
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Calyx_Length");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "red")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "blue")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "yellow")
   // plot corolla_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Calyx_Width");
     // plot calyx_Width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Calyx_Width");
     // plot corolla_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("corolla_length");
     // plot calyx_Length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("corolla_width");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();



